.. :changelog:

History
-------

0.10 (2019-05-23)
+++++++++++++++++

* Upgraded to more recent version of fluent.runtime (0.12 with modifications)
* Fixed ``use_isolating`` behavior (BDI characters are now inserted for HTML messages)
* Thread-safety fixes for loading bundles.
* Corrected order of using 'locales' directories found via ``INSTALLED_APPS`` to
  be consistent with normal Django convention.


0.9.1 (2019-03-02)
++++++++++++++++++

* Changed development autoreload mechanism to not interfere with Django's
  development server autoreload.
* Bug fix for case when invalid mode is specified in template tag.
* Various fixes and improvements to middlewares (plus tests)
* Thread-safe Bundle
* Method for configuring ``ftlmsg`` via context processor.

0.9 (2018-09-10)
++++++++++++++++

* Working version
* Depends on our version of python-fluent

0.0.1 (2018-05-19)
++++++++++++++++++

* First release on PyPI - empty placeholder package
